pub enum Fsa {
Dfa,
}Expand description
The type of the Finite State Automaton to be used.
Variants
Dfa
The Deterministic Finite Automaton. It is a deterministic finite automaton that eagerly computes all the state transitions. It is the fastest type of finite automaton, but it is also the most memory-consuming. In particular, construction time and space required could be exponential in the worst case.